@@ -19,6 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <glib/gi18n.h>
 #include <vncdisplay.h>
 #include <gdk/gdkkeysyms.h>
@@ -150,14 +151,6 @@ vnc_tab_get_tooltip (VinagreTab *tab)
 				  _("Dimensions:"), vnc_display_get_width (VNC_DISPLAY (vnc_tab->priv->vnc)), vnc_display_get_height (VNC_DISPLAY (vnc_tab->priv->vnc)));
 }
 
-static GdkPixbuf *
-vnc_tab_get_screenshot (VinagreTab *tab)
-{
-  VinagreVncTab *vnc_tab = VINAGRE_VNC_TAB (tab);
-
-  return vnc_display_get_pixbuf (VNC_DISPLAY (vnc_tab->priv->vnc));
-}
-
 static void
 vinagre_vnc_tab_finalize (GObject *object)
 {
@@ -223,7 +216,6 @@ vinagre_vnc_tab_class_init (VinagreVncTabClass *klass)
   tab_class->impl_get_tooltip = vnc_tab_get_tooltip;
   tab_class->impl_get_connected_actions = vnc_get_connected_actions;
   tab_class->impl_get_initialized_actions = vnc_get_initialized_actions;
-  tab_class->impl_get_screenshot = vnc_tab_get_screenshot;
 
   g_object_class_install_property (object_class,
 				   PROP_ORIGINAL_WIDTH,
@@ -357,7 +349,7 @@ vnc_auth_unsupported_cb (VncDisplay *vnc, guint auth_type, VinagreVncTab *vnc_ta
   emphasis = g_strdup_printf ("<i>%s</i>", name);
 
   /* Translators: %s is a host name or IP address; %u is a code error (number). */
-  g_string_printf (message, _("Authentication method to host %s is unsupported. (%u)"),
+  g_string_printf (message, _("Authentication method for host %s is unsupported. (%u)"),
 		   emphasis,
 		   auth_type);
 
@@ -509,6 +501,7 @@ vnc_authentication_cb (VncDisplay *vnc, GValueArray *credList, VinagreVncTab *vn
 					     host,
 					     need_username,
 					     need_password,
+					     8,
 					     &username,
 					     &password,
 					     &save_in_keyring))
@@ -576,7 +569,7 @@ vnc_pointer_ungrab_cb (VncDisplay *vnc, VinagreVncTab *vnc_tab)
 static void
 vnc_bell_cb (VncDisplay *vnc, VinagreVncTab *vnc_tab)
 {
-  gdk_window_beep (GTK_WIDGET (vnc_tab)->window);
+  gdk_window_beep (gtk_widget_get_window (GTK_WIDGET (vnc_tab)));
 }
 
 static void
@@ -680,7 +673,7 @@ create_initialized_actions (VinagreVncTab *tab)
   a->paths[1] = g_strdup ("/ToolBar");
   a->paths[2] = NULL;
   a->action = gtk_action_new ("VNCMachineSendCtrlAltDel",
-			      _("Send Ctrl-Alt-Del"),
+			      _("_Send Ctrl-Alt-Del"),
 			      _("Sends Ctrl+Alt+Del to the remote machine"),
 			      "preferences-desktop-keyboard-shortcuts");
   gtk_action_set_is_important (a->action, TRUE);
@@ -797,6 +790,7 @@ vinagre_vnc_tab_init (VinagreVncTab *vnc_tab)
   gtk_container_add (GTK_CONTAINER (vnc_tab->priv->align), vnc_tab->priv->vnc);
 
   vinagre_tab_add_view (VINAGRE_TAB (vnc_tab), vnc_tab->priv->align);
+  vinagre_tab_set_has_screenshot (VINAGRE_TAB (vnc_tab), TRUE);
 
   g_signal_connect (vnc_tab->priv->vnc,
 		    "vnc-connected",
@@ -877,7 +871,7 @@ vinagre_vnc_tab_new (VinagreConnection *conn,
 void
 vinagre_vnc_tab_send_ctrlaltdel (VinagreVncTab *tab)
 {
-  guint keys[] = { GDK_Control_L, GDK_Alt_L, GDK_Delete };
+  guint keys[] = { GDK_KEY_Control_L, GDK_KEY_Alt_L, GDK_KEY_Delete };
 
   g_return_if_fail (VINAGRE_IS_VNC_TAB (tab));
 
