@@ -147,9 +147,7 @@ vinagre_notebook_show_hide_tabs (VinagreNotebook *nb)
   fs = vinagre_window_is_fullscreen (nb->priv->window);
   n = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 
-  g_object_get (vinagre_prefs_get_default (),
-		"always-show-tabs", &always,
-		NULL);
+  always = g_settings_get_boolean (vinagre_prefs_get_default_gsettings (), "always-show-tabs");
 
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb),
 			      ((n > 1) || (always)) && !fs);
@@ -202,6 +200,7 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
 {
   gboolean       active;
   GtkActionGroup *action_group;
+  GtkAction      *action;
 
   active = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) > 0;
   action_group = vinagre_window_get_connected_action (nb->priv->window);
@@ -212,6 +211,11 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
 	   (vinagre_tab_get_state (VINAGRE_TAB (nb->priv->active_tab)) == VINAGRE_TAB_STATE_CONNECTED);
   gtk_action_group_set_sensitive (action_group, active);
 
+  action = gtk_action_group_get_action (action_group, "MachineTakeScreenshot");
+  gtk_action_set_sensitive (action, active &&
+				    nb->priv->active_tab &&
+				    vinagre_tab_get_has_screenshot (nb->priv->active_tab));
+
   if (nb->priv->active_tab)
     {
       GtkWidget *spinner, *icon;
@@ -358,10 +362,10 @@ unmerge_tab_ui (VinagreNotebook *nb)
 }
 
 static void 
-vinagre_notebook_page_switched (GtkNotebook     *notebook,
-				GtkNotebookPage *pg,
-				gint            page_num, 
-				gpointer        data)
+vinagre_notebook_page_switched (GtkNotebook *notebook,
+				GtkWidget   *page,
+				gint         page_num,
+				gpointer     data)
 {
   VinagreNotebook *nb = VINAGRE_NOTEBOOK (notebook);
   VinagreTab *tab;
@@ -381,13 +385,11 @@ vinagre_notebook_page_switched (GtkNotebook     *notebook,
 static void
 vinagre_notebook_page_removed_cb (VinagreNotebook *nb)
 {
-  gint n;
-
   if ((gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) == 0) &&
       (vinagre_window_is_fullscreen (nb->priv->window)))
     vinagre_window_toggle_fullscreen (nb->priv->window);
 
-vinagre_notebook_show_hide_tabs (nb);
+  vinagre_notebook_show_hide_tabs (nb);
 }
 
 static void
@@ -411,8 +413,9 @@ vinagre_notebook_init (VinagreNotebook *nb)
 		    "switch-page",
 		    G_CALLBACK (vinagre_notebook_page_switched),
 		    NULL);
-  g_signal_connect_swapped (vinagre_prefs_get_default (),
-			    "notify::always-show-tabs",
+
+  g_signal_connect_swapped (vinagre_prefs_get_default_gsettings (),
+			    "changed::always-show-tabs",
 			     G_CALLBACK (vinagre_notebook_show_hide_tabs),
 			     nb);
 }
@@ -611,7 +614,6 @@ vinagre_notebook_add_tab (VinagreNotebook *nb,
 			  gint           position)
 {
   GtkWidget      *label;
-  GtkActionGroup *action_group;
   int            pos;
 
   g_return_if_fail (VINAGRE_IS_NOTEBOOK (nb));
@@ -665,7 +667,6 @@ vinagre_notebook_close_tab (VinagreNotebook *nb,
 			    VinagreTab      *tab)
 {
   gint           position;
-  GtkActionGroup *action_group;
   GtkNotebook    *notebook;
   VinagreTab     *previous_active_tab;
 
@@ -731,6 +732,12 @@ vinagre_notebook_close_active_tab (VinagreNotebook *nb)
   vinagre_notebook_close_tab (nb, nb->priv->active_tab);
 }
 
+/**
+ * vinagre_notebook_get_active_tab:
+ * @nb: A Notebook
+ *
+ * Return value: (transfer none):
+ */
 VinagreTab *
 vinagre_notebook_get_active_tab (VinagreNotebook *nb)
 {
@@ -739,6 +746,12 @@ vinagre_notebook_get_active_tab (VinagreNotebook *nb)
   return nb->priv->active_tab;
 }
 
+/**
+ * vinagre_notebook_get_tabs:
+ * @nb: A Notebook
+ *
+ * Return value: (transfer none) (element-type VinagreTab):
+ */
 GSList *
 vinagre_notebook_get_tabs (VinagreNotebook *nb)
 {
